import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["prefixCls", "className", "onChange", "toolbars", "toolbarsMode", "visible", "visibleEditor", "previewProps"];
import React, { useState, createRef, useRef, useEffect, useImperativeHandle, useMemo } from 'react';
import CodeMirror from './components/CodeMirror';
import MarkdownPreview from '@uiw/react-markdown-preview';
import ToolBar from './components/ToolBar';
import { getCommands, getModeCommands } from './commands';
import "./index.css";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export * from './commands';
export default /*#__PURE__*/React.forwardRef(MarkdownEditor);

function MarkdownEditor(props, ref) {
  var _props$prefixCls = props.prefixCls,
      prefixCls = _props$prefixCls === void 0 ? 'md-editor' : _props$prefixCls,
      className = props.className,
      _onChange = props.onChange,
      _props$toolbars = props.toolbars,
      toolbars = _props$toolbars === void 0 ? getCommands() : _props$toolbars,
      _props$toolbarsMode = props.toolbarsMode,
      toolbarsMode = _props$toolbarsMode === void 0 ? getModeCommands() : _props$toolbarsMode,
      _props$visible = props.visible,
      visible = _props$visible === void 0 ? true : _props$visible,
      _props$visibleEditor = props.visibleEditor,
      visibleEditor = _props$visibleEditor === void 0 ? true : _props$visibleEditor,
      _props$previewProps = props.previewProps,
      previewProps = _props$previewProps === void 0 ? {} : _props$previewProps,
      codemirrorProps = _objectWithoutPropertiesLoose(props, _excluded);

  var _useState = useState(props.value || ''),
      value = _useState[0],
      setValue = _useState[1];

  var codeMirror = /*#__PURE__*/createRef();
  var previewContainer = useRef();

  var _useState2 = useState(),
      editor = _useState2[0],
      setEditor = _useState2[1];

  var container = useRef(null);
  var containerEditor = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      editor: editor,
      preview: previewContainer.current
    };
  });
  useEffect(function () {
    if (codeMirror.current) {
      setEditor(codeMirror.current.editor);
    }
  }, [codeMirror.current]);
  var toolBarProps = {
    editor: editor,
    preview: previewContainer.current,
    container: container.current,
    containerEditor: containerEditor.current,
    editorProps: props
  };
  var codeEditor = useMemo(function () {
    return /*#__PURE__*/_jsx(CodeMirror, _extends({
      visibleEditor: visibleEditor
    }, codemirrorProps, {
      ref: codeMirror,
      onChange: function onChange(editor, data) {
        setValue(editor.getValue());
        _onChange && _onChange(editor, data, editor.getValue());
      }
    }));
  }, [visibleEditor, codemirrorProps]);
  return /*#__PURE__*/_jsx("div", {
    ref: container,
    children: /*#__PURE__*/_jsxs("div", {
      className: (prefixCls || '') + " " + (className || ''),
      children: [/*#__PURE__*/_jsx(ToolBar, _extends({}, toolBarProps, {
        toolbars: toolbarsMode,
        mode: true
      })), /*#__PURE__*/_jsx(ToolBar, _extends({}, toolBarProps, {
        toolbars: toolbars
      })), /*#__PURE__*/_jsxs("div", {
        className: prefixCls + "-content",
        children: [/*#__PURE__*/_jsx("div", {
          className: prefixCls + "-content-editor",
          ref: containerEditor,
          children: visibleEditor && codeEditor
        }), /*#__PURE__*/_jsx(MarkdownPreview, _extends({}, previewProps, {
          "data-visible": !!visible,
          className: prefixCls + "-preview",
          ref: function ref(instance) {
            if (instance && instance.mdp) {
              previewContainer.current = instance.mdp.current;
            }
          },
          source: value
        }))]
      })]
    })
  });
}
//# sourceMappingURL=index.js.map